@@ -38,7 +38,6 @@ from .vers_check import VersionCheck
 
 
 class TmuxConfig:
-
     #
     #  I have forked a tpm that uses TPM_BIN to use the right tmux
     #  context. If you just use one version of tmux, this does not
@@ -84,7 +83,7 @@ class TmuxConfig:
     #
     #  Default binary, if non given
     #
-    tmux_bin = "tmux"
+    tmux_bin = os.getenv("TMUX_BIN") or "tmux"
 
     lib_version = __version__
 
@@ -332,7 +331,6 @@ class TmuxConfig:
         #  how to override the edit key
         #
         self.edit_config()
-
         if self.plugin_handler and self.plugins.found():
             w(
                 """#======================================================
@@ -442,7 +440,6 @@ class TmuxConfig:
         #
         lines: list[str] = []
         for raw_line in cmd.split("\n"):
-            ## print(f">> raw_line [{raw_line}]")
             #
             #  Returns a list of lines. If input contained a -N and notes
             #  are not supported by this tmux, the note is extracted and
@@ -457,22 +454,15 @@ class TmuxConfig:
             for line in self.filter_note(raw_line.strip()):
                 lines.append(line)
 
-        if self._write_stdout:
-            #
-            #  Used for displaying plugin settings
-            #
+        with open(self.conf_file, "a", encoding="utf-8") as f:
             for line in lines:
-                print(line)
-        else:
-            with open(self.conf_file, "a", encoding="utf-8") as f:
-                for line in lines:
-                    if self.use_embedded_scripts and (btick_unescaped(line)):
-                        raise SyntaxError(
-                            "Un-escaped back-ticks can not be present in "
-                            + "the generated config when\n"
-                            + "embedded_scripts are used!"
-                        )
-                    f.write(f"{line}{eol}")
+                if self.use_embedded_scripts and (btick_unescaped(line)):
+                    raise SyntaxError(
+                        "Un-escaped back-ticks can not be present in "
+                        + "the generated config when\n"
+                        + "embedded_scripts are used!"
+                    )
+                f.write(f"{line}{eol}")
 
     def filter_note(self, line: str):
         """Returns list of lines, if notes are not supported
@@ -492,7 +482,6 @@ class TmuxConfig:
         parts = line.split("-N")
         pre = parts[0].strip()
         post = parts[1].strip()
-        print(f">> pre [{pre}] [{post}]")
         if not post:
             # Propably an -N at end of line, so not related to a note
             return [pre]
@@ -560,7 +549,7 @@ class TmuxConfig:
         # Do a basic sanity check
         if self.is_tmux_bin(cmd):
             self.tmux_bin = cmd
-            self.define_tmux_vers()
+            self.define_tmux_vers(tmux_bin=cmd)
         else:
             sys.exit(f"ERROR: tmux bin seems invalid: {cmd}")
 
@@ -569,27 +558,11 @@ class TmuxConfig:
             #  Use the first that gives something
             cmd = self.find_cmd_1() or self.find_cmd_2() or self.find_cmd_3()
 
-        if cmd:
-            # the asdf check needs to know what version this is
-            self.use_tmux_bin(cmd)
-        #
-        #  asdf refers to bins via its shim dir, where versions cant be
-        #  identified, since it depends on other ENV variables,
-        #  in this case try to extract a full path to the tmux bin itself,
-        #  but make sure not to expand an asdf path that has already
-        #  been processed!
-        #
-        if cmd.find(".asdf") > -1 and cmd.find("/installs/") < 0:
-            if not self.is_tmux_bin(cmd):
-                print(f"ERROR: asdf tmux does not seem to be valid: {cmd}")
-                sys.exit(1)
-            cmd_asdf = (
-                f'{cmd.split("shims/")[0]}installs/tmux/'
-                f'{self.vers.get().split("-")[0]}/bin/tmux'
-            )
-            self.use_tmux_bin(cmd_asdf)
+        self.expand_cmd_path(cmd)
 
-        if not cmd:
+        # ==== 1 =
+
+        if not self.tmux_bin:
             #  tmux not found abort
             print("ERROR could not find tmux binary, aborting")
             sys.exit(1)
@@ -598,7 +571,7 @@ class TmuxConfig:
     def is_tmate(self):
         return self.tmux_bin.find("tmate") > -1
 
-    def is_tmux_bin(self, cmd: str = "") -> bool:
+    def is_tmux_bin(self, cmd: str) -> bool:
         """Only checks if the requested bin seems to be a tmux or tmate,
         checking name and doing simplified version check, ie if
         the second part of version is int"""
@@ -624,7 +597,6 @@ class TmuxConfig:
         if not tmux_bin:
             tmux_bin = self.tmux_bin
         vers_found = run_shell(f"{tmux_bin} -V | cut -d' ' -f2")
-
         self.vers = VersionCheck(vers_found, vers)
 
     #
@@ -649,15 +621,8 @@ class TmuxConfig:
 
     def find_cmd_2(self):
         """Next check PATH"""
-        cmd = ""
-        try:
-            c = run_shell("command -v tmux")
-        except subprocess.CalledProcessError:
-            c = ""
-        if c and c.lower().find("not found") < 0:
-            cmd = c
-            print(f"found {cmd} in PATH")
-        return cmd
+        print(f"find_cmd_2()")
+        return self.full_path_cmd()
 
     def find_cmd_3(self):
         """Finally try some likely locations"""
@@ -673,6 +638,44 @@ class TmuxConfig:
                 break
         return cmd
 
+    def expand_cmd_path(self, cmd):
+        #
+        #  asdf refers to bins via its shim dir, where versions cant be
+        #  identified, since it depends on other ENV variables,
+        #  in this case try to extract a full path to the tmux bin itself,
+        #  but make sure not to expand an asdf path that has already
+        #  been processed!
+        #  Any process starting in the same dir as tmux was started will
+        #  inherrit potential local asdf tmux selection, but processes
+        #  starting in other dirs will use asdf default version.
+        #  By expanding the initial shim into a full version,
+        #  the correct tmux will be used in all instances.
+        #
+        if cmd:
+            # the asdf check needs to know what version this is
+            self.use_tmux_bin(cmd)
+        # get full path notation for tmux
+        cmd = self.full_path_cmd(cmd)
+        if cmd.find(".asdf") > -1 and cmd.find("/installs/") < 0:
+            if not self.is_tmux_bin(cmd):
+                print(f"ERROR: asdf tmux does not seem to be valid: {cmd}")
+                sys.exit(1)
+            #
+            #  Convert asdf shim into absolute path
+            #
+            cmd_asdf = (
+                f'{cmd.split("shims/")[0]}installs/tmux/'
+                f'{self.vers.get().split("-")[0]}/bin/tmux'
+            )
+            self.use_tmux_bin(cmd_asdf)
+
+    def full_path_cmd(self, cmd="tmux"):
+        c = run_shell(f"command -v {cmd}")
+        if c and c.lower().find("not found") < 0:
+            cmd = c
+            print(f"found {cmd} in PATH")
+        return cmd
+
     def remove_conf_file(self):
         if os.path.exists(self.conf_file):
             #  Ensure we start with an empty file
